Attribute VB_Name = "modIni"
'CookieRevised adds:
'Always use Option Explicit as the first line of every module, form, class...
Option Explicit

'// VB Web Code Example
'// www.vbweb.co.uk

' DLL declarations
Private Declare Function GetPrivateProfileString Lib "kernel32" Alias "GetPrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Long, ByVal lpFileName As String) As Long
Private Declare Function WritePrivateProfileString Lib "kernel32" Alias "WritePrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpString As Any, ByVal lpFileName As String) As Long

'// Functions
'Function GetFromINI(....)
'  CookieRevised adds:
'  Always define what the type of the returned variable will be. If you don't do this
'  it will be a variant, which can cause potential problems in other routines.
'  => Function GetFromINI(....) As String
Function GetFromINI(sSection As String, sKey As String, sDefault As String, sIniFile As String) As String
    Dim sBuffer As String, lRet As Long
    ' Fill String with 255 spaces
    '   CookieRevised adds:
    '   This will not fill the buffer with spaces, but with null characters; a space is ascii code 32.
    '   Nevertheless, it is indeed better to fill it with null characters though.
    sBuffer = String$(255, 0)
    lRet = GetPrivateProfileString(sSection, sKey, sDefault, sBuffer, Len(sBuffer), sIniFile)
    
    ' CookieRevised adds:
    ' Instead of using the IF THEN ELSE, why not directly include the default value in
    ' the API call in the first place? The only reason would be that if the API failed
    ' you still would return a default value instead of an empty string. But this case
    ' is so extremely rare that such situations will almost never happen. And if they
    ' do happen, you would have far more problems with other stuff then only this
    ' routine anyways. In short, use the 'default' parameter of the API.
    '   ' Call DLL
    '   lRet = GetPrivateProfileString(sSection, sKey, "", sBuffer, Len(sBuffer), sIniFile)
    '   If lRet = 0 Then
    '       'CookieRevised adds:
    '       'Don't include the saving in a reading routine like this, it is not logical
    '       'and may even produce errors in certain situations. Also, there is no need
    '       'to save a default setting if you read out settings and the value isn't
    '       'found as you will return the default value anyways.
    '       '    ' DLL failed, save default
    '       '    If sDefault <> "" Then AddToINI sSection, sKey, sDefault, sIniFile
    '       GetFromINI = sDefault
    '   Else
    '       ' DLL successful
    '       ' return string
    '       GetFromINI = Left(sBuffer, InStr(sBuffer, Chr(0)) - 1)
    '   End If
    
    GetFromINI = Left$(sBuffer, InStr(sBuffer, Chr(0)) - 1)

End Function

'// Returns True if successful. If section does not
'// exist it creates it.
Function AddToINI(sSection As String, sKey As String, sValue As String, sIniFile As String) As Boolean
    'Dim lRet As Long
    '  Call DLL
    '  CookieRevised adds:
    '  Make the following shorter:
    '    lRet = WritePrivateProfileString(sSection, sKey, sValue, sIniFile)
    '    AddToINI = (lRet)
    AddToINI = WritePrivateProfileString(sSection, sKey, sValue, sIniFile)
End Function

Function Log(LogEntry As String)
    frmLog.lblLog.Caption = frmLog.lblLog.Caption & Chr(10) & "> " & LogEntry
End Function

Function BadLoad(LogEntry As String)
    frmLog.lblLog.Caption = frmLog.lblLog.Caption & Chr(10) & "> BadLoad: " & LogEntry
End Function
